==> haskell-x509-system-1.6.6-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-FI2k9deSEVV5GnOFNDT6Fl
key:                  x509-system-1.6.6-FI2k9deSEVV5GnOFNDT6Fl
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  c8e0e931f94729c5c6861bb1ce93f1b0
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-FI2k9deSEVV5GnOFNDT6Fl
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-7cn5WyyMGJaIrbl0mbr3En process-1.6.11.0
    x509-1.7.5-1JKMyBJT3zD6Jrah3i2Cg0
    x509-store-1.6.7-D8tJF0thcHb64PHbPxM5gu

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.6-239-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-4tZMpaEV5zzBiXVoKtorjU
key:                  x509-system-1.6.6-4tZMpaEV5zzBiXVoKtorjU
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  b2a0789caacac6547ed88bc72b45b26e
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-4tZMpaEV5zzBiXVoKtorjU
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-9ffjE5PCK27D26W6pk3HfA process-1.6.11.0
    x509-1.7.5-6CsAbKhYNocGg2QWftqBmP
    x509-store-1.6.7-5qPGSdxi32m2hyZtmB7Zrv

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
